@@ -1,4 +1,4 @@
-#!D:\bld\gnuradio_1647905002728\_h_env\python.exe
+#!D:\bld\gnuradio_1654702770372\_h_env\python.exe
 
 import sys
 import pmt
@@ -7,11 +7,11 @@ from argparse import ArgumentParser
 
 parser = ArgumentParser()
 parser.add_argument("-H", "--host", default="localhost",
-                  help="Hostname to connect to (default=%(default)r)")
+                    help="Hostname to connect to (default=%(default)r)")
 parser.add_argument("-p", "--port", type=int, default=9090,
-                  help="Port of Controlport instance on host (default=%(default)r)")
+                    help="Port of Controlport instance on host (default=%(default)r)")
 parser.add_argument("-a", "--alias", default="gr uhd usrp source0",
-                  help="The UHD block's alias to control (default=%(default)r)")
+                    help="The UHD block's alias to control (default=%(default)r)")
 parser.add_argument("command", metavar="COMMAND")
 parser.add_argument("value", metavar="VALUE")
 args = parser.parse_args()
@@ -29,7 +29,8 @@ if(cmd == "antenna"):
 else:
     val = pmt.from_double(float(val))
 
-radiosys = GNURadioControlPortClient(host=args.host, port=args.port, rpcmethod='thrift')
+radiosys = GNURadioControlPortClient(
+    host=args.host, port=args.port, rpcmethod='thrift')
 radio = radiosys.client
 
 radio.postMessage(args.alias, port, pmt.cons(pmt.intern(cmd), val))
